@@ -9,6 +9,7 @@
 #include <config.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include "global.h"
 #include "file.h"
 #include "fileopctx.h"
 #include "main.h"
@@ -219,7 +220,6 @@ perform_action (GList *names, GdkDragAction action, char *destdir)
 		} while (result != 0);
 
 		g_free (dest_name);
-		break;
 	}
 
 	file_op_context_destroy (ctx);
@@ -268,12 +268,19 @@ drop_url_on_directory (GdkDragContext *context, GtkSelectionData *selection_data
 
 		f = fopen (template, "w");
 		if (f) {
+			char *icon;
+			
 			fprintf (f, "URL: %s\n", selection_data->data);
 			fclose (f);
 
 			gnome_metadata_set (template, "desktop-url",
 					    strlen (selection_data->data) + 1,
 					    selection_data->data);
+
+			icon = g_concat_dir_and_file (ICONDIR, "gnome-http-url.png");
+			gnome_metadata_set (template, "icon-filename",
+					    strlen (icon) + 1, icon);
+			g_free (icon);
 		}
 	}
 
