@@ -183,7 +183,7 @@ void
 set_hintbar (char *str)
 {
   /*gtk_label_set (GTK_LABEL (current_panel_ptr->panel->status), str);*/
-	x_flush_events ();
+/*	x_flush_events (); */
 }
 
 void
@@ -281,10 +281,10 @@ void configure_box (void);
 
 GtkCheckMenuItem *gnome_toggle_snap (void);
 GnomeUIInfo gnome_panel_new_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("_Terminal"), N_("Launch a new terminal in the current directory"), gnome_open_terminal},
+	 GNOMEUIINFO_ITEM_NONE(N_("_Terminal"), N_("Launch a new terminal in the current directory"), gnome_open_terminal),
 	/* If this ever changes, make sure you update create_new_menu accordingly. */
-	{ GNOME_APP_UI_ITEM, N_("_Directory..."), N_("Creates a new directory"), gnome_mkdir_cmd },
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
+	GNOMEUIINFO_ITEM_NONE( N_("_Directory..."), N_("Creates a new directory"), gnome_mkdir_cmd ),
+	GNOMEUIINFO_END
 };
 
 
@@ -299,46 +299,44 @@ GnomeUIInfo gnome_panel_file_menu [] = {
 	/*  Gnumeric Spreadsheet */
 	/*  Text Document */
 	/*  etc... */
-	{ GNOME_APP_UI_SUBTREE, N_("_New"), 	       NULL, gnome_panel_new_menu},
-	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_ITEM, N_("_Open"),              N_("Opens the selected files"), gnome_open_files },
-/*	{ GNOME_APP_UI_ITEM, N_("Open _FTP site"),     N_("Opens an FTP site"), ftplink_cmd },*/
-	{ GNOME_APP_UI_ITEM, N_("_Copy..."),           N_("Copy files"), copy_cmd, NULL},
-	{ GNOME_APP_UI_ITEM, N_("_Delete..."),         N_("Delete files from disk"), delete_cmd, NULL, NULL, 0, NULL, 'd', GDK_CONTROL_MASK},
-	{ GNOME_APP_UI_ITEM, N_("_Move..."),           N_("Rename or move files"), ren_cmd },
-	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_ITEM, N_("C_lose"),             N_("Close this panel"), gnome_close_panel, NULL,
-	  NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
-	  GNOME_KEY_NAME_CLOSE, GNOME_KEY_MOD_CLOSE, NULL },
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
+	GNOMEUIINFO_MENU_NEW_SUBTREE(gnome_panel_new_menu),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_OPEN_ITEM( gnome_open_files, GNOME_STOCK_PIXMAP_OPEN),
+/*	GNOMEUIINFO_ITEM_NONE( N_("Open _FTP site"),  N_("Opens an FTP site"), ftplink_cmd },*/
+	GNOMEUIINFO_ITEM_STOCK(N_("_Copy..."), N_("Copy files"), copy_cmd, GNOME_STOCK_PIXMAP_COPY),
+	GNOMEUIINFO_ITEM_STOCK(N_("_Delete..."), N_("Delete files"), delete_cmd, GNOME_STOCK_PIXMAP_REMOVE),
+        GNOMEUIINFO_ITEM_NONE(N_("_Move..."), N_("Rename or move files"), ren_cmd),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_CLOSE_ITEM(gnome_close_panel, NULL),
+        GNOMEUIINFO_END
 };
 
 GnomeUIInfo gnome_panel_edit_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("Select _All"),        N_("Select all files in the current Panel"), gnome_select_all_cmd, NULL, NULL, 0, NULL, 'a', GDK_CONTROL_MASK  },
-	{ GNOME_APP_UI_ITEM, N_("_Select Files..."),   N_("Select a group of files"), select_cmd },
-	{ GNOME_APP_UI_ITEM, N_("_Invert Selection"),  N_("Reverses the list of tagged files"), reverse_selection_cmd },
-	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_ITEM, N_("_Rescan Directory"),  N_("Rescan the directory contents"), reread_cmd },
-	{ GNOME_APP_UI_SEPARATOR },
+	{ GNOME_APP_UI_ITEM,  N_("Select _All"),        N_("Select all files in the current Panel"), gnome_select_all_cmd,
+	  NULL, NULL, 0, NULL, 'a', GDK_CONTROL_MASK  },
+	GNOMEUIINFO_ITEM_NONE( N_("_Select Files..."),  N_("Select a group of files"), select_cmd ),
+	GNOMEUIINFO_ITEM_NONE( N_("_Invert Selection"), N_("Reverses the list of tagged files"), reverse_selection_cmd ),
+	GNOMEUIINFO_SEPARATOR,
+        GNOMEUIINFO_ITEM_NONE( N_("_Rescan Directory"), N_("Rescan the directory contents"), reread_cmd ),
+	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM(gnome_configure_box, NULL),
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo gnome_panel_view_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("Icon View"), NULL, gnome_icon_view_cmd, NULL},
-	{ GNOME_APP_UI_ITEM, N_("Partial View"), NULL, gnome_partial_view_cmd, NULL},
-	{ GNOME_APP_UI_ITEM, N_("Full View"), NULL, gnome_full_view_cmd, NULL},
-	{ GNOME_APP_UI_ITEM, N_("Custom View"), NULL, gnome_custom_view_cmd, NULL},
-	{GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
+	GNOMEUIINFO_RADIOITEM(N_("Icon View"), NULL, gnome_icon_view_cmd,NULL),
+	GNOMEUIINFO_RADIOITEM(N_("Partial View"), NULL, gnome_partial_view_cmd,NULL),
+	GNOMEUIINFO_RADIOITEM(N_("Full View"), NULL, gnome_full_view_cmd,NULL),
+	GNOMEUIINFO_RADIOITEM(N_("Custom View"), NULL, gnome_custom_view_cmd,NULL),
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo gnome_panel_layout_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("_Sort By..."),     N_("Confirmation settings"), gnome_sort_cmd },
-	{ GNOME_APP_UI_ITEM, N_("_Filter View..."),    N_("Global option settings"), gnome_filter_cmd },
-	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_RADIOITEMS, NULL , NULL, gnome_panel_view_menu},
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
+	GNOMEUIINFO_ITEM_NONE( N_("_Sort By..."),     N_("Confirmation settings"), gnome_sort_cmd ),
+	GNOMEUIINFO_ITEM_NONE( N_("_Filter View..."),    N_("Global option settings"), gnome_filter_cmd ),
+	GNOMEUIINFO_SEPARATOR,
+        GNOMEUIINFO_RADIOLIST( gnome_panel_view_menu),
+	GNOMEUIINFO_END
 };
 
 GnomeUIInfo gnome_panel_commands_menu [] = {
@@ -351,33 +349,32 @@ GnomeUIInfo gnome_panel_commands_menu [] = {
 	{ GNOME_APP_UI_ITEM, N_("_Run Command in panel..."),N_("Run a command and put the results in a panel"), gnome_external_panelize },
 
 #ifdef USE_VFS					  
-	{ GNOME_APP_UI_ITEM, N_("_Active VFS list..."),N_("List of active virtual file systems"), reselect_vfs },
+	 GNOMEUIINFO_ITEM_NONE(N_("_Active VFS list..."),N_("List of active virtual file systems"), reselect_vfs),
 #endif
 #ifdef USE_EXT2FSLIB
 	/*does this do anything?*/
 /*	{ GNOME_APP_UI_ITEM, N_("_Undelete files (ext2fs only)..."), N_("Recover deleted files"), undelete_cmd },*/
 #endif
 #ifdef WITH_BACKGROUND
-	{ GNOME_APP_UI_ITEM, N_("_Background jobs..."),   N_("List of background operations"), jobs_cmd },
+	GNOMEUIINFO_ITEM_NONE( N_("_Background jobs..."),   N_("List of background operations"), jobs_cmd ),
 #endif
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
+        GNOMEUIINFO_END
 };
 
 
 GnomeUIInfo gnome_panel_about_menu [] = {
 /*	GNOMEUIINFO_HELP ("midnight-commander"), */
-	{ GNOME_APP_UI_ITEM, N_("_About"),              N_("Information on this program"), gnome_about_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT },
+	GNOMEUIINFO_MENU_ABOUT_ITEM( gnome_about_cmd,NULL),
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo gnome_panel_menu [] = {
-	{ GNOME_APP_UI_SUBTREE, N_("_File"),     NULL, &gnome_panel_file_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("_Edit"),     NULL, &gnome_panel_edit_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("_Layout"),   NULL, &gnome_panel_layout_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("_Commands"), NULL, &gnome_panel_commands_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("_Help"),     NULL, &gnome_panel_about_menu },
-	{ GNOME_APP_UI_ENDOFINFO, 0, 0 }
+        GNOMEUIINFO_MENU_FILE_TREE(gnome_panel_file_menu),
+        GNOMEUIINFO_MENU_EDIT_TREE(gnome_panel_edit_menu),
+        GNOMEUIINFO_SUBTREE(N_("_Layout"),gnome_panel_layout_menu),
+        GNOMEUIINFO_SUBTREE(N_("_Commands"),gnome_panel_commands_menu),
+        GNOMEUIINFO_MENU_HELP_TREE(gnome_panel_about_menu),
+        GNOMEUIINFO_END
 };
 
 GtkCheckMenuItem *
@@ -393,10 +390,11 @@ gnome_init_panels (void)
 	other_panel_ptr = NULL;
 }
 
-static void
+static int
 gnome_close_panel_event (GtkWidget *widget, GdkEvent *event, WPanel *panel)
 {
 	gnome_close_panel (widget, panel);
+	return TRUE;
 }
 
 static void
