@@ -8,8 +8,8 @@
 
 
 #include <config.h>
-#include <gnome.h>
 #include "global.h"
+#include <gnome.h>
 #include "panel.h"
 #include "cmd.h"
 #include "dialog.h"
@@ -94,6 +94,13 @@ dicon_properties (GtkWidget *widget, DesktopIconInfo *dii)
 	gtk_widget_show_all (dlg);
 	if (gnome_dialog_run (GNOME_DIALOG (dlg)) == 0)
 		retval = gnome_file_property_dialog_make_changes (GNOME_FILE_PROPERTY_DIALOG (dlg));
+
+	/*
+	 * Apply: desktop icon name change and url change
+	 */
+	if (dii->url)
+		desktop_icon_update_url (dii);
+	
 	gtk_widget_destroy (dlg);
 	g_free(path);
 	if (retval)
@@ -529,7 +536,6 @@ gpopup_do_popup (GdkEventButton *event, WPanel *from_panel,
 
 	/* Connect to the deactivation signal to be able to quit our
            modal main loop */
-
 	id = gtk_signal_connect (GTK_OBJECT (menu), "deactivate",
 				 (GtkSignalFunc) menu_shell_deactivated,
 				 NULL);
