@@ -30,10 +30,18 @@
 #include "tree.h"
 #include "../vfs/vfs.h"
 
-/* "$Id: dir.c,v 1.12 1999/01/27 01:08:47 timur Exp $" */
+/* "$Id: dir.c,v 1.14 1999/02/10 21:58:09 unammx Exp $" */
 
-/* If true show files starting with a dot */
+/*
+ * If true show files starting with a dot.
+ *
+ * In GNOME we default to not showing them.
+ */
+#ifdef HAVE_GNOME
+int show_dot_files = 0;
+#else
 int show_dot_files = 1;
+#endif
 
 /* If true show files ending in ~ */
 int show_backups = 0;
@@ -552,6 +560,7 @@ int do_reload_dir (dir_list *list, sortfn *sort, int count, int rev,
     dirp = mc_opendir (".");
     if (!dirp) {
  	clean_dir (list, count);
+	tree_store_end_check ();
 	return set_zero_dir (list);
     }
 
@@ -582,6 +591,7 @@ int do_reload_dir (dir_list *list, sortfn *sort, int count, int rev,
              IMHO it's not worthwhile). 
 	    clean_dir (&dir_copy, count);
              */
+	    tree_store_end_check ();
 	    return next_free;
 	}
 	
