@@ -135,10 +135,14 @@ typedef struct {
     void *tree;
     void *icons;
     void *notebook;
-    void *scrollbar;
     void *status;
     void *ministatus;
     void *tree_scrolled_window;
+
+#ifdef NEW_GNOME_LIBS
+#else
+    void *scrollbar;
+#endif
 	
     void *filter_w;		/* A WInput* */
     void *current_dir;		/* A WInput* */
